import type * as Types from './types';
export default class HttpAuthClient {
    private key;
    private secret;
    constructor(key?: string, secret?: string);
    permissions(): Promise<string[] | null>;
    balance(): Promise<{
        currency_code: Types.CurrencyCode;
        amount: number;
        available: number;
    }[] | null>;
    collateral(): Promise<{
        collateral: number;
        open_position_pnl: number;
        require_collateral: number;
        keep_rate: number;
    } | null>;
    collateralAccounts(): Promise<({
        currency_code: "JPY";
        amount: number;
    } | {
        currency_code: "BTC";
        amount: number;
    })[] | null>;
    addresses(): Promise<Types.Address[] | null>;
    coinIns(): Promise<{
        id: number;
        order_id: string;
        currency_code: Types.CurrencyCode;
        amount: number;
        address: string;
        tx_hash: string;
        status: Types.CoinStatus;
        event_date: string;
    }[] | null>;
    coinOuts(): Promise<{
        id: number;
        order_id: string;
        currency_code: Types.CurrencyCode;
        amount: number;
        address: string;
        tx_hash: string;
        fee: number;
        additional_fee: number;
        status: Types.CoinStatus;
        event_date: string;
    }[] | null>;
    bankAccounts(): Promise<{
        id: number;
        is_verified: boolean;
        bank_name: string;
        branch_name: string;
        account_type: string;
        account_number: string;
        account_name: string;
    }[] | null>;
    deposits(): Promise<{
        id: number;
        order_id: string;
        currency_code: "JPY";
        amount: number;
        status: Types.CoinStatus;
        event_date: string;
    }[] | null>;
    withdraw(body: Types.Withdraw): Promise<unknown>;
    widthdrawals(): Promise<{
        id: number;
        order_id: string;
        currency_code: "JPY";
        amount: number;
        status: Types.CoinStatus;
        event_date: string;
    }[] | null>;
    sendChildOrder(body: Types.ChildOrderBody): Promise<unknown>;
    cancelChildOrder(body: Types.CancelChildOrder): Promise<unknown>;
    sendParentOrder(body: Types.ParentOrderBody): Promise<unknown>;
    cancelParentOrder(body: Types.CancelParentOrder): Promise<unknown>;
    cancelAllChildOrders(product: Types.ProductCode): Promise<unknown>;
    childOrders(product: Types.ProductCode): Promise<{
        id: number;
        child_order_id: string;
        product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
        side: "BUY" | "SELL";
        child_order_type: Types.OrderType;
        price: number;
        average_price: number;
        size: number;
        child_order_state: Types.OrderState;
        expire_date: string;
        child_order_date: string;
        child_order_acceptance_id: string;
        outstanding_size: number;
        cancel_size: number;
        executed_size: number;
        total_commission: number;
    }[] | null>;
    parentOrders(product: Types.ProductCode): Promise<({
        id: number;
        parent_order_id: string;
        product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
        side: "BUY" | "SELL";
        parent_order_type: "STOP" | "LIMIT" | "MARKET" | "STOP_LIMIT" | "TRAIL";
        price: number;
        average_price: number;
        size: number;
        parent_order_state: Types.OrderState;
        expire_date: string;
        parent_order_date: string;
        parent_order_acceptance_id: string;
        outstanding_size: number;
        cancel_size: number;
        executed_size: number;
        total_commission: number;
    } | {
        id: number;
        parent_order_id: string;
        product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
        side: "BUY" | "SELL";
        parent_order_type: "SIMPLE" | "IFD" | "OCO" | "IFDOCO";
        price: number;
        average_price: number;
        size: number;
        parent_order_state: string;
        expire_date: string;
        parent_order_date: string;
        parent_order_acceptance_id: string;
        outstanding_size: number;
        cancel_size: number;
        executed_size: number;
        total_commission: number;
    })[] | null>;
    parentOrderDetail(id: string): Promise<Types.ParentOrderDetail | null>;
    executions(product: Types.ProductCode): Promise<({
        id: number;
        side: "BUY";
        price: number;
        size: number;
        exec_date: string;
        buy_child_order_acceptance_id: string;
        sell_child_order_acceptance_id: string;
    } | {
        id: number;
        side: "SELL";
        price: number;
        size: number;
        exec_date: string;
        buy_child_order_acceptance_id: string;
        sell_child_order_acceptance_id: string;
    })[] | null>;
    balanceHistory(currency: Types.CurrencyCode): Promise<{
        id: number;
        trade_date: string;
        event_date: string;
        product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
        currency_code: Types.CurrencyCode;
        trade_type: Types.TradeType;
        price: number;
        amount: number;
        quantity: number;
        commission: number;
        balance: number;
        order_id: string;
    }[] | null>;
    positions(product: 'FX_BTC_JPY'): Promise<{
        product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
        side: "BUY" | "SELL";
        price: number;
        size: number;
        commission: number;
        swap_point_accumulate: number;
        require_collateral: number;
        open_date: string;
        leverage: number;
        pnl: number;
        sfd: number;
    }[] | null>;
    collateralHistory(): Promise<{
        id: number;
        currency_code: Types.CurrencyCode;
        change: number;
        amount: number;
        reason_code: string;
        date: string;
    }[] | null>;
    tradingCommission(product: Types.ProductCode): Promise<{
        commission_rate: number;
    } | null>;
    private get;
    private post;
    private request;
}
