"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = __importStar(require("node-fetch"));
const url_1 = require("url");
const crypto_1 = require("crypto");
class HttpAuthClient {
    constructor(key, secret) {
        if (!key || !secret) {
            throw new Error('API key and/or secret are required.');
        }
        this.key = key;
        this.secret = secret;
    }
    permissions() {
        return this.get('getpermissions', {});
    }
    balance() {
        return this.get('getbalance', {});
    }
    collateral() {
        return this.get('getcollateral', {});
    }
    collateralAccounts() {
        return this.get('getcollateralaccounts', {});
    }
    addresses() {
        return this.get('getaddresses', {});
    }
    coinIns() {
        return this.get('getcoinins', {});
    }
    coinOuts() {
        return this.get('getcoinouts', {});
    }
    bankAccounts() {
        return this.get('getbankaccounts', {});
    }
    deposits() {
        return this.get('getdeposits', {});
    }
    withdraw(body) {
        return this.post('withdraw', body);
    }
    widthdrawals() {
        return this.get('getwidthdrawals', {});
    }
    sendChildOrder(body) {
        return this.post('sendchildorder', body);
    }
    cancelChildOrder(body) {
        return this.post('cancelchildorder', body);
    }
    sendParentOrder(body) {
        return this.post('sendparentorder', body);
    }
    cancelParentOrder(body) {
        return this.post('cancelparentorder', body);
    }
    cancelAllChildOrders(product) {
        return this.post('cancelallchildorders', { product_code: product });
    }
    childOrders(product) {
        return this.get('getchildorders', { product_code: product });
    }
    parentOrders(product) {
        return this.get('getparentorders', { product_code: product });
    }
    parentOrderDetail(id) {
        return this.get('getparentorder', { parent_order_id: id });
    }
    executions(product) {
        return this.get('getexecutions', { product_code: product });
    }
    balanceHistory(currency) {
        return this.get('getbalancehistory', { currency_code: currency });
    }
    positions(product) {
        return this.get('getpositions', { product_code: product });
    }
    collateralHistory() {
        return this.get('getcollateralhistory', {});
    }
    tradingCommission(product) {
        return this.get('gettradingcommission', { product_code: product });
    }
    get(method, params) {
        return this.request('GET', `/v1/me/${method}`, params);
    }
    post(method, params) {
        return this.request('POST', `/v1/me/${method}`, {}, params);
    }
    request(method, path, query, bodyObj) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = new url_1.URL(`https://api.bitflyer.com${path}`);
            // eslint-disable-next-line no-return-assign
            if (query)
                Object.entries(query).forEach(([k, v]) => url.search = `${k}=${v}`);
            const timestamp = Date.now().toString();
            const body = bodyObj ? JSON.stringify(bodyObj) : '';
            const text = timestamp + method + url.pathname + url.search + body;
            const sign = crypto_1.createHmac('sha256', this.secret).update(text).digest('hex');
            const headers = new node_fetch_1.Headers();
            headers.append('ACCESS-KEY', this.key);
            headers.append('ACCESS-TIMESTAMP', timestamp);
            headers.append('ACCESS-SIGN', sign);
            headers.append('Content-Type', 'application/json');
            const request = method === 'GET'
                ? new node_fetch_1.Request(url.toString(), { headers, method })
                : new node_fetch_1.Request(url.toString(), { headers, method, body });
            const res = yield node_fetch_1.default(request);
            if (!res.ok) {
                throw new Error(res.statusText);
            }
            try {
                return yield res.json();
            }
            catch (_a) {
                return null;
            }
        });
    }
}
exports.default = HttpAuthClient;
