import io from 'socket.io-client';
import { Observable, ReplaySubject } from 'rxjs';
import type * as Types from './types';
declare type ProductCode = 'BTC_JPY' | 'FX_BTC_JPY' | 'ETH_BTC';
export default class RealtimeClient {
    protected socket: ReturnType<typeof io>;
    protected channel$: ReplaySubject<string>;
    constructor();
    unsubscribe(): void;
    board(product: ProductCode): Observable<{
        mid_price: number;
        bids: {
            price: number;
            size: number;
        }[];
        asks: {
            price: number;
            size: number;
        }[];
    }>;
    boardSnapshot(product: ProductCode): Observable<{
        mid_price: number;
        bids: {
            price: number;
            size: number;
        }[];
        asks: {
            price: number;
            size: number;
        }[];
    }>;
    executions(product: ProductCode): Observable<{
        id: number;
        side: "BUY";
        price: number;
        size: number;
        exec_date: string;
        buy_child_order_acceptance_id: string;
        sell_child_order_acceptance_id: string;
    } | {
        id: number;
        side: "SELL";
        price: number;
        size: number;
        exec_date: string;
        buy_child_order_acceptance_id: string;
        sell_child_order_acceptance_id: string;
    }>;
    ticker(product: ProductCode): Observable<{
        product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
        state: Types.BoardState;
        timestamp: string;
        tick_id: number;
        best_bid: number;
        best_ask: number;
        best_bid_size: number;
        best_ask_size: number;
        total_bid_depth: number;
        total_ask_depth: number;
        market_bid_size: number;
        market_ask_size: number;
        ltp: number;
        volume: number;
        volume_by_product: number;
    }>;
    protected subscribe<T>(channel: string): Observable<T>;
    protected auth(key: string, secret: string): Promise<void>;
}
export {};
