"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = require("crypto");
const socket_io_client_1 = __importDefault(require("socket.io-client"));
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
class RealtimeClient {
    constructor() {
        this.channel$ = new rxjs_1.ReplaySubject();
        this.socket = socket_io_client_1.default('https://io.lightstream.bitflyer.com', { transports: ['websocket'] });
        this.socket.on('connect', () => {
            this.channel$.pipe(operators_1.distinct()).subscribe((channel) => this.socket.emit('subscribe', channel));
        });
    }
    unsubscribe() {
        this.socket.disconnect();
    }
    board(product) {
        return this.subscribe(`lightning_board_${product}`);
    }
    boardSnapshot(product) {
        return this.subscribe(`lightning_board_snapshot_${product}`);
    }
    executions(product) {
        return this.subscribe(`lightning_executions_${product}`).pipe(operators_1.mergeAll());
    }
    ticker(product) {
        return this.subscribe(`lightning_ticker_${product}`);
    }
    subscribe(channel) {
        this.channel$.next(channel);
        return new rxjs_1.Observable((subscriber) => {
            this.socket.on(channel, (message) => subscriber.next(message));
        });
    }
    auth(key, secret) {
        const timestamp = Date.now();
        const nonce = crypto_1.randomBytes(16).toString('hex');
        const signature = crypto_1.createHmac('sha256', secret)
            .update(timestamp + nonce).digest('hex');
        return new Promise((resolve, reject) => {
            this.socket.emit('auth', {
                api_key: key, timestamp, nonce, signature,
            }, (err) => {
                if (err)
                    reject(err);
                resolve();
            });
        });
    }
}
exports.default = RealtimeClient;
